@@ -1,22 +1,25 @@
 package ParseUtil::Domain;
-$ParseUtil::Domain::VERSION = '2.422';
+$ParseUtil::Domain::VERSION = '2.423';
 # VERSION
 
+require Exporter;
+our @ISA = qw(Exporter);
+
 use Modern::Perl;
 use Carp;
-use utf8::all;
 use autobox;
 use autobox::Core;
 use List::MoreUtils qw/any/;
-use Perl6::Export::Attrs;
 use Net::IDN::Encode ':all';
 use Net::IDN::Punycode ':all';
 use Net::IDN::Nameprep;
 #use Smart::Comments;
 
 use ParseUtil::Domain::ConfigData;
+our @EXPORT = qw(parse_domain puny_convert);
+our %EXPORT_TAGS = (parse => [qw/parse_domain/], simple => [qw/puny_convert/]);
 
-sub parse_domain : Export(:parse) {
+sub parse_domain  {
     my $name = shift;
     ### testing : $name
     my @name_segments = $name->split(qr{\Q@\E});
@@ -58,7 +61,7 @@ sub parse_domain : Export(:parse) {
 
 }
 
-sub puny_convert : Export(:simple) {
+sub puny_convert {
     my $domain = shift;
     my @keys;
     if ( $domain =~ /\.?xn--/ ) {
@@ -220,6 +223,7 @@ sub _puny_decode {
 }
 
 1;
+
 __END__
 
 =encoding utf8
@@ -229,7 +233,7 @@ __END__
 ParseUtil::Domain - Domain parser and puny encoder/decoder.
 
 
-=for HTML <a href="https://travis-ci.org/heytrav/ParseUtil-Domain"><img src="https://travis-ci.org/heytrav/ParseUtil-Domain.svg?branch=master"></a>
+=for HTML <a href="https://travis-ci.org/heytrav/ParseUtil-Domain"><img src="https://travis-ci.org/heytrav/ParseUtil-Domain.svg?branch=remove-utf8"></a>
 
 
 =head1 SYNOPSIS
